import sys
import os
from pathlib import Path
import PyQt5
from PyQt5 import QtCore
from PyQt5.QtWidgets import *
from PyQt5.QtWidgets import QMainWindow, QApplication
from PyQt5.QtCore import QTimer, Qt
from PyQt5.QtGui import QFont, QWindow, QIcon
import time

from MSPyBentley import *
from MSPyBentleyGeom import *
from MSPyECObjects import *
from MSPyDgnPlatform import *
from MSPyDgnView import *
from MSPyMstnPlatform import *

import la_solutions_utilities  as la_utilities
import la_solutions_qt_widgets as la_widgets 

#
# Hello World 2 example Python app.
#
# This demonstrates a PyQt5 user-interface (UX) window containing a small number of UX widgets.
# This example defines a window base class.  Its purpose is to own a timer that pumps windows messages
# so that MicroStation remains responsive.
# Registering a timer with a 0 start interval will cause the timer method to execute every time the Qt Windows event loop finishes. 
# Calling PyCadInputQueue.PythonMainLoop from the timer will allow MicroStation's input loop to execute allowing use of the 
# MicroStation UX whilst the Qt window is displayed.
#
# The MainWindow class inherits from MainWindowBase class.  The base class starts the message pump, the
# MainWindow class owns the displayable widgets.
#         

class MainWindow(la_widgets.MainWindowBase):
    # Initialize the main window class
    def __init__(self):
        # Call the parent class's constructor to initialize the main window
        super().__init__("MicroStation Python")
        
        #   Class method to create a label
        def makeLabel (self)->QLabel:
            label = QLabel(self)
            label.setText("<h1>Hello, World!</h1><h2>Version 2</h2>")
            label.move(100,85)
            label.adjustSize ()
            label.setStyleSheet (
                        'background-color: #888888;'  # hex code for medium gray
            )
            return label

        # Set the background color of the main window
        self.setStyleSheet (
            'background-color: #888888;'  # hex code for medium gray
        )
        
        # Set the size of the main window (x, y, width, height)
        self.setGeometry (
            0,  # initial x-coordinate
            0,  # initial y-coordinate
            420,  # width in pixels
            180   # height in pixels
        )
        
        # Make the main window stay on top of other windows.
        # Unfortunately the Qt window floats above other apps. as well as MicroStation
        self.setWindowFlags(
            QtCore.Qt.WindowStaysOnTopHint
        )        
        
        # Create a label to display our text
        self.textLabel = makeLabel(self)        
    
        
if __name__ == "__main__":  # check if this script is being run directly (not imported as a module)
    app = QApplication.instance()   # get the existing application instance, if any
    
    if app is None:  # check if no application instance exists
        app = QApplication(sys.argv)   # create a new application instance with command-line arguments
    
    window = MainWindow()   # create an instance of the main window class
    window.show()   # show the main window
    
    app.exec()  # run the application's event loop until the window is closed
