import sys
import la_solutions_utilities  as la_utilities

from PyQt5.QtWidgets import QMainWindow, QApplication
from PyQt5.QtGui import QFont, QWindow, QIcon
from PyQt5.QtCore import QTimer, Qt

def updateMstn ():
    """Used to pump windows messages to MicroStation"""
    PyCadInputQueue.PythonMainLoop()

def MessageLoopTimer ()->QTimer:
    """Timer updates MicroStation each second to ensure that this Python window does not monopolise the message loop"""
    timer = QTimer()   # create a QTimer object for updating the message loop
    timer.timeout.connect(updateMstn)  # connect the timer's timeout signal to the updateMstn function
    timer.start()   # start the timer with an interval of 1 second (1,000 milliseconds)
    return timer

class MainWindowBase(QMainWindow):
    """MainWindowBase is a Qt Window class intended to be inherited by other Window classes"""
    
    # Initialize the main window class.
    # This constructor accepts a caption for the window
    def __init__(self, caption: str):
        # Call the parent class's constructor to initialize the main window
        super().__init__()
        
        iconPath = la_utilities.getFileFromScriptFolder ('smiley-icon.png')
        self.setWindowIcon(QIcon(iconPath))
        # Set the title of the main window
        if not caption:
            #   No caption provided
            pass
        else:
            self.setWindowTitle(caption)
        
        #   Timer updates MicroStation each second to ensure that this Python window does not monopolise the message loop.
        #   The timer variable is a member of the MainWindowBase class and remains alive while the window is active.
        _messageLoopTimer = MessageLoopTimer ()
            
